#
# Conditional build:
%bcond_without	static_libs	# static library
%bcond_without	tcmalloc	# tcmalloc usage
%bcond_without	tests		# unit tests

%ifarch x32
%undefine	with_tcmalloc
%endif
Summary:	LevelDB - key-value store library
Summary(pl.UTF-8):	LevelDB - biblioteka bazy danych klucz-wartość
Name:		leveldb
Version:	1.23
Release:	2
License:	BSD
Group:		Libraries
#Source0Download: https://github.com/google/leveldb/releases
Source0:	https://github.com/google/leveldb/archive/%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	afbde776fb8760312009963f09a586c7
Patch0:		%{name}-system-libs.patch
Patch1:		%{name}-rtti.patch
URL:		https://github.com/google/leveldb
BuildRequires:	cmake >= 3.9
%{?with_tests:BuildRequires:	gmock-devel}
%{?with_tests:BuildRequires:	google-benchmark-devel}
%{?with_tests:BuildRequires:	gtest-devel}
BuildRequires:	libstdc++-devel >= 6:4.7
%{?with_tcmalloc:BuildRequires:	libtcmalloc-devel}
BuildRequires:	snappy-devel
# sqlite3-devel kyotocabinet-devel for benchmarks
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
LevelDB is a fast key-value storage library written at Google that
provides an ordered mapping from string keys to string values.

%description -l pl.UTF-8
LevelDB to napisana w Google szybka biblioteka do przechowywania par
klucz-wartość, udostępniająca uporządkowane odwzorowanie z kluczy
będących łańcuchami znaków do wartości tego samego typu.

%package devel
Summary:	Header files for LevelDB library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki LevelDB
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	libstdc++-devel >= 6:4.7
%{?with_tcmalloc:Requires: libtcmalloc-devel}
Requires:	snappy-devel

%description devel
Header files for LevelDB library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki LevelDB.

%package static
Summary:	Static LevelDB library
Summary(pl.UTF-8):	Statyczna biblioteka LevelDB
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static LevelDB library.

%description static -l pl.UTF-8
Statyczna biblioteka LevelDB.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
%if %{with static_libs}
install -d build-static
cd build-static
%cmake .. \
	-DBUILD_SHARED_LIBS:BOOL=OFF \
	%{!?with_tests:-DLEVELDB_BUILD_TESTS:BOOL=OFF} \
	-DLEVELDB_BUILD_BENCHMARKS:BOOL=OFF

%{__make}
cd ..
%endif

install -d build
cd build
%cmake .. \
	%{!?with_tests:-DLEVELDB_BUILD_TESTS:BOOL=OFF} \
	-DLEVELDB_BUILD_BENCHMARKS:BOOL=OFF

%{__make}

%if %{with tests}
ctest
%endif

%install
rm -rf $RPM_BUILD_ROOT

%if %{with static_libs}
%{__make} -C build-static install \
	DESTDIR=$RPM_BUILD_ROOT
%endif

%{__make} -C build install \
	DESTDIR=$RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS LICENSE NEWS README.md TODO
%attr(755,root,root) %{_libdir}/libleveldb.so.*.*
%attr(755,root,root) %ghost %{_libdir}/libleveldb.so.1

%files devel
%defattr(644,root,root,755)
%doc doc/*
%attr(755,root,root) %{_libdir}/libleveldb.so
%{_includedir}/leveldb
%{_libdir}/cmake/leveldb

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libleveldb.a
%endif
%changelog
* Thu Feb 17 2022 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/leveldb.git;a=log;h=master

* Thu Feb 17 2022 Jakub Bogusz <qboosh@pld-linux.org> 986eb9b
- added rtti patch (don't disable rtti, ceph relies on it); release 2

* Tue Feb 15 2022 Jakub Bogusz <qboosh@pld-linux.org> f24a9a9
- updated to 1.23
- removed obsolete soname patch
- added system-libs patch (use system gmock/gtest/benchmark libs)

* Fri May 22 2020 Jakub Bogusz <qboosh@pld-linux.org> 957891c
- updated to 1.22

* Sat Mar 30 2019 Jakub Bogusz <qboosh@pld-linux.org> 5afc60f
- updated to 1.21
- added soname patch to fix missing soname after build system change (cmake now)

* Fri Apr 28 2017 Jakub Bogusz <qboosh@pld-linux.org> dad93a6
- updated to 1.20

* Sun Dec 25 2016 Jakub Bogusz <qboosh@pld-linux.org> 2287b48
- updated to 1.19

* Sat Mar 26 2016 Elan Ruusamäe <glen@delfi.ee> afb564a
- run tests

* Sat Mar 26 2016 Elan Ruusamäe <glen@delfi.ee> 3b7ebd8
- up to 1.18

* Sun Nov 15 2015 Jan Rękorajski <baggins@pld-linux.org> 210efea
- release 3 (by relup.sh)

* Tue Feb 24 2015 Jan Rękorajski <baggins@pld-linux.org> 2f3003e
- x32 rebuild
- release 2 (by relup.sh)

* Tue Dec 30 2014 Jan Rękorajski <baggins@pld-linux.org> bcb0d92
- fix tcmalloc bcond for devel package

* Tue Dec 30 2014 Jan Rękorajski <baggins@pld-linux.org> 426abf9
- added tcmalloc bcond

* Sat Mar 08 2014 Jakub Bogusz <qboosh@pld-linux.org> e268866
- updated to 1.15.0

* Tue Oct 15 2013 Jakub Bogusz <qboosh@pld-linux.org> 0d660fc
- updated to 1.14.0

* Tue Aug 27 2013 Jakub Bogusz <qboosh@pld-linux.org> a84fa3f
- updated to 1.13.0

* Mon Jul 08 2013 Jakub Bogusz <qboosh@pld-linux.org> 3ffa640
- updated to 1.12.0

* Sun Jun 16 2013 Jakub Bogusz <qboosh@pld-linux.org> d2a9272
- updated to 1.11.0

* Mon Apr 01 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 37b02e3
- release 2 (by relup.sh)

* Wed Jan 09 2013 Jakub Bogusz <qboosh@pld-linux.org> 82aeaef
- updated to 1.9.0

* Sun Jan 06 2013 Jakub Bogusz <qboosh@pld-linux.org> 2281969
- updated to 1.8.0

